@@ -20,6 +20,7 @@ from damask_parse.utils import (
     get_header_lines,
     parse_damask_spectral_version_info,
     volume_element_from_2D_microstructure,
+    add_volume_element_buffer_zones,
 )
 from damask_parse import __version__ as damask_parse_version
 from matflow.scripting import get_wrapper_script
@@ -92,6 +93,7 @@ def read_seeds_from_random(seeds_path, orientation_coordinate_system, phase_labe
         'orientations': {
             'type': 'euler',
             'euler_angles': eulers,
+            'euler_degrees': True,
             'orientation_coordinate_system': orientation_coordinate_system,
             # DAMASK uses x//a alignment for hexagonal system (unlike the more
             # common y//b):
@@ -220,7 +222,10 @@ def write_microstructure_seeds(path, microstructure_seeds):
 
     grid_size = microstructure_seeds['grid_size']
     position = microstructure_seeds['position']
+
     eulers = microstructure_seeds['orientations']['euler_angles']
+    if not microstructure_seeds['orientations']['euler_degrees']:
+        eulers = np.rad2deg(eulers)
 
     data = np.hstack([position, eulers, np.arange(1, len(position) + 1)[:, None]])
 
@@ -257,6 +262,8 @@ def write_microstructure_new_orientations(path, microstructure_seeds, orientatio
         raise NotImplementedError(msg)
 
     eulers = orientations['euler_angles']
+    if not orientations['euler_degrees']:
+        eulers = np.rad2deg(eulers)
 
     data = np.hstack([position, eulers, np.arange(1, len(position) + 1)[:, None]])
 
@@ -292,6 +299,17 @@ def volume_element_from_microstructure_image(microstructure_image, depth, image_
     return out
 
 
+@func_mapper(task='modify_volume_element', method='add_buffer_zones')
+def modify_volume_element_add_buffer_zones(volume_element, buffer_sizes, 
+                                           phase_ids, phase_labels, homog_label, order):
+    out = {
+        'volume_element': add_volume_element_buffer_zones(
+            volume_element, buffer_sizes, phase_ids, phase_labels, homog_label, order
+        )
+    }
+    return out
+
+
 @func_mapper(task='visualise_volume_element', method='VTK')
 def visualise_volume_element(volume_element):
     from damask import Geom
